@@ -14,9 +14,21 @@ from .goal_metadata import GoalMetadata
 logger = logging.getLogger(__name__)
 
 
+@dataclass
+class Vector3d:
+    # There is probably a class like this in python somewhere
+    # but i don't know where it is.
+    # TODO change later, potentially rename?
+    x: float = 0
+    y: float = 0
+    z: float = 0
+
+
 class ConfigManager(object):
 
     DEFAULT_CLIPPING_PLANE_FAR = 15.0
+    DEFAULT_ROOM_DIMENSIONS = Vector3d(x=10, y=3, z=10)
+
     # Normal metadata plus metadata for all hidden objects
     CONFIG_METADATA_TIER_ORACLE = 'oracle'
     # No metadata, except for the images, depth masks, object masks,
@@ -39,6 +51,7 @@ class ConfigManager(object):
 
     CONFIG_DEFAULT_SECTION = 'MCS'
 
+    CONFIG_EVALUATION_NAME = 'evaluation_name'
     CONFIG_HISTORY_ENABLED = 'history_enabled'
     CONFIG_METADATA_TIER = 'metadata'
     CONFIG_NOISE_ENABLED = 'noise_enabled'
@@ -46,6 +59,7 @@ class ConfigManager(object):
     CONFIG_SAVE_DEBUG_JSON = 'save_debug_json'
     CONFIG_SEED = 'seed'
     CONFIG_SIZE = 'size'
+    CONFIG_TEAM = 'team'
     CONFIG_VIDEO_ENABLED = 'video_enabled'
 
     # Please keep the aspect ratio as 3:2 because the IntPhys scenes are built
@@ -82,6 +96,13 @@ class ConfigManager(object):
                 str(self.SCREEN_WIDTH_DEFAULT)
             )
 
+    def get_evaluation_name(self):
+        return self._config.get(
+            self.CONFIG_DEFAULT_SECTION,
+            self.CONFIG_EVALUATION_NAME,
+            fallback=''
+        )
+
     def get_metadata_tier(self):
         # Environment variable override for metadata property
         metadata_env_var = os.getenv('MCS_METADATA_LEVEL', None)
@@ -116,6 +137,13 @@ class ConfigManager(object):
             fallback=self.SCREEN_WIDTH_DEFAULT
         )
 
+    def get_team(self):
+        return self._config.get(
+            self.CONFIG_DEFAULT_SECTION,
+            self.CONFIG_TEAM,
+            fallback=''
+        )
+
     def is_history_enabled(self):
         return self._config.getboolean(
             self.CONFIG_DEFAULT_SECTION,
@@ -294,6 +322,24 @@ class PhysicsConfigSchema(Schema):
         return PhysicsConfig(**data)
 
 
+class FloorHolesAndTexturesXZConfigSchema(Schema):
+    x = fields.Int()
+    z = fields.Int()
+
+    @post_load
+    def make_holes_config(self, data, **kwargs):
+        return FloorHolesAndTexturesXZConfig(**data)
+
+
+class FloorTexturesConfigSchema(Schema):
+    material = fields.Str()
+    positions = fields.List(fields.Nested(FloorHolesAndTexturesXZConfigSchema))
+
+    @post_load
+    def make_floor_textures_config(self, data, **kwargs):
+        return FloorTexturesConfig(**data)
+
+
 class ShowConfigSchema(Schema):
     stepBegin = fields.Int()
     position = fields.Nested(Vector3dSchema)
@@ -380,6 +426,7 @@ class SceneObjectSchema(Schema):
     resizes = fields.List(fields.Nested(SizeConfigSchema))
     rotates = fields.List(fields.Nested(MoveConfigSchema))
     salientMaterials = fields.List(fields.Str())
+    seesaw = fields.Bool()
     shows = fields.List(fields.Nested(ShowConfigSchema))
     shrouds = fields.List(fields.Nested(StepBeginEndConfigSchema))
     states = fields.List(fields.List(fields.Str(), allow_none=True))
@@ -419,6 +466,8 @@ class SceneConfigurationSchema(Schema):
     version = fields.Integer()
     wallMaterial = fields.Str()
     wallProperties = fields.Nested(PhysicsConfigSchema)
+    holes = fields.List(fields.Nested(FloorHolesAndTexturesXZConfigSchema))
+    floorTextures = fields.List(fields.Nested(FloorTexturesConfigSchema))
 
     # These are deprecated, but needed for Eval 3 backwards compatibility
     evaluation = fields.Str(allow_none=True)
@@ -434,16 +483,6 @@ class SceneConfigurationSchema(Schema):
         return SceneConfiguration(**data)
 
 
-@dataclass
-class Vector3d:
-    # There is probably a class like this in python somewhere
-    # but i don't know where it is.
-    # TODO change later, potentially rename?
-    x: float = 0
-    y: float = 0
-    z: float = 0
-
-
 @dataclass
 class RoomMaterials:
     front: str = None
@@ -515,6 +554,18 @@ class PhysicsConfig:
     staticFriction: float = None
 
 
+@dataclass
+class FloorHolesAndTexturesXZConfig:
+    x: int = None
+    z: int = None
+
+
+@dataclass
+class FloorTexturesConfig:
+    material: str
+    positions: List[FloorHolesAndTexturesXZConfig] = None
+
+
 @dataclass
 class ShowConfig:
     stepBegin: int
@@ -586,6 +637,7 @@ class SceneObject:
     resizes: List[SizeConfig] = None
     rotates: List[MoveConfig] = None
     salientMaterials: List[str] = None
+    seesaw: bool = None
     shows: List[ShowConfig] = None
     shrouds: List[StepBeginEndConfig] = None
     states: List[List[str]] = None
@@ -616,12 +668,15 @@ class SceneConfiguration:
     objects: List[SceneObject] = field(default_factory=list)
     observation: bool = False  # deprecated; please use intuitivePhysics
     performerStart: PerformerStart = None
-    roomDimensions: Vector3d = None
+    roomDimensions: Vector3d = field(
+        default=ConfigManager.DEFAULT_ROOM_DIMENSIONS)
     roomMaterials: RoomMaterials = None
     screenshot: bool = False  # developer use only; for the image generator
     version: int = None
     wallMaterial: str = None
     wallProperties: PhysicsConfig = None
+    holes: List[FloorHolesAndTexturesXZConfig] = field(default_factory=list)
+    floorTextures: List[FloorTexturesConfig] = field(default_factory=list)
 
     # These are deprecated, but needed for Eval 3 backwards compatibility
     evaluation: str = None
