@@ -123,8 +123,10 @@ class GoalMetadata:
 @unique
 class GoalCategory(Enum):
     """
-    Each goal will have a "category" string and a "metadata" dict with one or
-    more properties depending on the "category".
+    Each goal dict will have a "category" string that describes the type of
+    scene (or, the type of task within the scene) being run. Each goal dict
+    will also have a "metadata" dict containing one or more properties
+    depending on the "category".
     """
 
     AGENTS = "agents"
@@ -142,12 +144,12 @@ class GoalCategory(Enum):
     These trials will demand a "common sense" understanding of agents, their
     behaviors, and their interactions with objects in the environment.
 
-    Parameters
-    ----------
-    choose : list of strings
-        The list of choices, one of which must be given in your call to
-        end_scene. For Agents goals, this value will always be
-        ["expected", "unexpected"].
+    Notes
+    -----
+    You are required to call `controller.end_scene()` at the end of each scene
+    with a continuous plausibility `rating`, from 0.0 (completely implausible)
+    to 1.0 (completely plausible). You are not required to also pass it a
+    `score`.
     """
 
     INTUITIVE_PHYSICS = "intuitive physics"
@@ -159,12 +161,14 @@ class GoalCategory(Enum):
     permanence or shape constancy. Inspired by Emmanuel Dupoux's "IntPhys: A
     Benchmark for Visual Intuitive Physics Reasoning" (http://intphys.com).
 
-    Parameters
-    ----------
-    choose : list of strings
-        The list of choices, one of which must be given in your call to
-        end_scene. For Intuitive Physics goals, this value will always be
-        ["plausible", "implausible"].
+    Notes
+    -----
+    You are required to call `controller.end_scene()` at the end of each scene
+    with a binary plausibility `rating` -- either 0 (implausible) or 1
+    (plausible) -- and a continuous plausibility `score` -- from 0.0
+    (completely implausible) to 1.0 (completely plausible). This is also
+    where you would submit any retrospective reporting on a per step basis via
+    `report`.
     """
 
     RETRIEVAL = "retrieval"
@@ -192,6 +196,8 @@ class GoalCategory(Enum):
 
     TRANSFERRAL = "transferral"
     """
+    NOT USED IN MCS EVAL 4+
+
     In a trial that has a transferral goal, you must find and pickup the
     first target object and put it down either next to or on top of the second
     target object. This may involve exploring the scene, avoiding obstacles,
@@ -251,6 +257,8 @@ class GoalCategory(Enum):
 
     TRAVERSAL = "traversal"
     """
+    NOT USED IN MCS EVAL 4+
+
     In a trial that has a traversal goal, you must find and move next to a
     target object. This may involve exploring the scene, and avoiding
     obstacles. These trials will demand a "common sense" understanding of
