@@ -26,10 +26,16 @@ class HistoryEventHandler(AbstractControllerSubscriber):
             if self.__history_writer:
                 self.__history_writer.check_file_written()
 
-            hist_info = {
-                payload.config.CONFIG_METADATA_TIER:
-                payload.config.get_metadata_tier()
-            }
+            hist_info = {}
+            hist_info[
+                payload.config.CONFIG_EVALUATION_NAME
+            ] = payload.config.get_evaluation_name()
+            hist_info[
+                payload.config.CONFIG_METADATA_TIER
+            ] = payload.config.get_metadata_tier()
+            hist_info[
+                payload.config.CONFIG_TEAM
+            ] = payload.config.get_team()
 
             # Create a new scene history writer with each new scene (config
             # data) so we always create a new, separate scene history file.
@@ -55,23 +61,34 @@ class HistoryEventHandler(AbstractControllerSubscriber):
             output=output,
             delta_time_millis=0)
 
-    def on_prediction(self, payload):
-        # add history step prediction attributes before add to the writer
-        # in the next step
-        if self.__history_item is not None:
-            self.__history_item.classification = payload.choice
-            self.__history_item.confidence = payload.confidence
-            self.__history_item.violations_xy_list = payload.violations_xy_list
-            self.__history_item.internal_state = payload.internal_state
-
     def on_end_scene(self, payload):
         if (
             self.__history_writer is not None and
             payload.config.is_history_enabled()
         ):
             self.__history_writer.add_step(self.__history_item)
+
+            # Loop back and fill out previous steps with retrospective report
+            if payload.report is not None:
+                for step in self.__history_writer.current_steps:
+                    currentStep = step.get("step")
+
+                    findStepInReport = (payload.report.get(
+                        currentStep) or
+                        payload.report.get(str(currentStep)))
+
+                    if(findStepInReport is not None):
+                        # Use classification and confidence rather than rating
+                        # and score to be compatible with old history files.
+                        step["classification"] = findStepInReport.get("rating")
+                        step["confidence"] = findStepInReport.get("score")
+                        step["violations_xy_list"] = findStepInReport.get(
+                            "violations_xy_list")
+                        step["internal_state"] = findStepInReport.get(
+                            "internal_state")
+
             self.__history_writer.write_history_file(
-                payload.choice, payload.confidence)
+                payload.rating, payload.score)
 
     def _get_filename_without_timestamp(self, filepath: pathlib.Path):
         return filepath.stem[:-16] + filepath.suffix
@@ -152,11 +169,13 @@ class HistoryWriter(object):
             self.current_steps.append(
                 dict(self.filter_history_output(step_obj)))
 
-    def write_history_file(self, classification, confidence):
+    def write_history_file(self, rating, score):
         """ Add the end score obj, create the object
             that will be written to file"""
-        self.end_score["classification"] = classification
-        self.end_score["confidence"] = str(confidence)
+        # Use classification and confidence rather than rating and score to be
+        # compatible with old history files.
+        self.end_score["classification"] = rating
+        self.end_score["confidence"] = str(score)
 
         self.history_obj["info"] = self.info_obj
         self.history_obj["steps"] = self.current_steps
