@@ -3,12 +3,14 @@ import os
 import shutil
 import unittest
 from types import SimpleNamespace
+from unittest.mock import ANY, MagicMock
 
 import numpy
 
 import machine_common_sense as mcs
 from machine_common_sense.config_manager import (ConfigManager,
                                                  SceneConfiguration, Vector3d)
+from machine_common_sense.controller_events import EndScenePayload, EventType
 from machine_common_sense.goal_metadata import GoalMetadata
 
 from .mock_controller import MOCK_VARIABLES, MockControllerAI2THOR
@@ -21,6 +23,7 @@ class TestController(unittest.TestCase):
 
     def setUp(self):
         self.controller = MockControllerAI2THOR()
+        self.controller._publish_event = MagicMock()
         self.controller.set_metadata_tier('default')
         self.maxDiff = None
 
@@ -31,9 +34,8 @@ class TestController(unittest.TestCase):
         for test_file in test_files:
             os.unlink(test_file)
         # if SCENE_HIST_DIR is empty, destroy it
-        if os.path.isdir(SCENE_HIST_DIR):
-            if not os.listdir(SCENE_HIST_DIR):
-                shutil.rmtree(SCENE_HIST_DIR)
+        if os.path.isdir(SCENE_HIST_DIR) and not os.listdir(SCENE_HIST_DIR):
+            shutil.rmtree(SCENE_HIST_DIR)
 
     def create_mock_scene_event(self, mock_scene_event_data):
         # Wrap the dict in a SimpleNamespace object to permit property access
@@ -271,16 +273,49 @@ class TestController(unittest.TestCase):
 
         return data
 
-    # Removed test for "end_scene" but it really only tested writing the
-    # history file.  We should add tests for sending events and then separately
-    # test the event handlers
-    # TODO
+    def test_end_scene(self):
+        test_payload = self.controller._create_event_payload_kwargs()
+
+        test_payload["rating"] = "plausible"
+        test_payload["score"] = 0.5
+        test_payload["report"] = {
+            1: {
+                "rating": "plausible",
+                "score": .75,
+                "violations_xy_list": [
+                    {
+                        "x": 1,
+                        "y": 1
+                    }
+                ]}
+        }
+
+        self.controller.end_scene("plausible", 0.5, {
+            1: {
+                "rating": "plausible",
+                "score": .75,
+                "violations_xy_list": [
+                    {
+                        "x": 1,
+                        "y": 1
+                    }
+                ]}
+        })
+
+        self.controller._publish_event.assert_called_with(
+            EventType.ON_END_SCENE,
+            EndScenePayload(**test_payload)
+        )
 
     def test_start_scene(self):
         self.controller.set_metadata_tier(
             ConfigManager.CONFIG_METADATA_TIER_ORACLE)
         output = self.controller.start_scene({'name': TEST_FILE_NAME})
         self.assertIsNotNone(output)
+        self.controller._publish_event.assert_called_with(
+            EventType.ON_START_SCENE,
+            ANY
+        )
         self.assertEqual(
             output.action_list,
             GoalMetadata.ACTION_LIST)
@@ -397,6 +432,21 @@ class TestController(unittest.TestCase):
         self.assertEqual(len(output.structural_object_list),
                          len(MOCK_VARIABLES['metadata']['structuralObjects']))
 
+    def test_step_events(self):
+        self.controller.set_metadata_tier(
+            ConfigManager.CONFIG_METADATA_TIER_ORACLE)
+        output = self.controller.start_scene({'name': TEST_FILE_NAME})
+        output = self.controller.step('MoveAhead')
+        self.controller._publish_event.assert_any_call(
+            EventType.ON_BEFORE_STEP,
+            ANY
+        )
+        self.controller._publish_event.assert_any_call(
+            EventType.ON_AFTER_STEP,
+            ANY
+        )
+        self.assertIsNotNone(output)
+
     def test_step_last_step(self):
         output = self.controller.start_scene({'name': TEST_FILE_NAME})
         self.controller.set_goal(mcs.GoalMetadata(last_step=0))
@@ -808,7 +858,9 @@ class TestController(unittest.TestCase):
         self.assertEqual(None, actual.name)
         self.assertEqual(None, actual.floorMaterial)
         self.assertEqual([], actual.objects)
-        self.assertEqual(None, actual.roomDimensions)
+        self.assertEqual(
+            ConfigManager.DEFAULT_ROOM_DIMENSIONS,
+            actual.roomDimensions)
         self.assertEqual(None, actual.goal)
 
         config = {"name": "name1", "roomDimensions": {"x": 1, "y": 2, "z": 3}}
